.. _contents:

NetworkX documentation
======================

.. only:: html

    :Release: |version|
    :Date: |today|

    Tutorial :download:`[PDF]  <networkx_tutorial.pdf>`

    Reference :download:`[PDF]  <networkx_reference.pdf>`

    Tutorial+Reference :download:`[HTML zip]  <networkx-documentation.zip>`

.. toctree::
   :maxdepth: 2

   overview
   download
   install
   tutorial/index
   reference/index
   test
   developer/index
   reference/history
   bibliography
   examples/index

.. only:: html

   - `Gallery <gallery.html>`_


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`
